@@ -11,7 +11,7 @@ iconFile = path.join(thisFolder,'movie.png')
 tooltip = _translate('Movie: play movie files')
 
 # only use _localized values for label values, nothing functional:
-_localized = {'movie': _translate('Movie file'), 'forceEndRoutine': _translate('Force end of Routine'), 
+_localized = {'movie': _translate('Movie file'), 'forceEndRoutine': _translate('Force end of Routine'),
               'backend':_translate('backend')}
 
 class MovieComponent(VisualComponent):
@@ -22,7 +22,8 @@ class MovieComponent(VisualComponent):
                 startType='time (s)', startVal=0.0,
                 stopType='duration (s)', stopVal=1.0,
                 startEstim='', durationEstim='',
-                forceEndRoutine=False, backend='avbin'):
+                forceEndRoutine=False, backend='moviepy',
+                noAudio=False):
         #initialise main parameters from base stimulus
         super(MovieComponent, self).__init__(exp,parentName,name=name, units=units,
                     pos=pos, size=size, ori=ori,
@@ -39,9 +40,12 @@ class MovieComponent(VisualComponent):
             updates='constant', allowedUpdates=['constant','set every repeat'],
             hint=_translate("A filename for the movie (including path)"),
             label=_localized['movie'])
-        self.params['backend']=Param(backend, valType='str', allowedVals=['avbin','opencv'],
+        self.params['backend']=Param(backend, valType='str', allowedVals=['moviepy','avbin','opencv'],
             hint=_translate("What underlying lib to use for loading movies"),
             label=_localized['backend'])
+        self.params["No audio"]=Param(noAudio, valType='bool', 
+            hint="Prevent the audio stream from being loaded/processed (moviepy and opencv only)",
+            label='No audio')
         self.params['forceEndRoutine']=Param(forceEndRoutine, valType='bool', allowedTypes=[],
             updates='constant', allowedUpdates=[],
             hint=_translate("Should the end of the movie cause the end of the routine (e.g. trial)?"),
@@ -62,10 +66,14 @@ class MovieComponent(VisualComponent):
             params = components.getInitVals(self.params)
         else:
             params = self.params
-        if self.params['backend'].val=='avbin':
+        if self.params['backend'].val=='moviepy':
+            buff.writeIndented("%s = visual.MovieStim3(win=win, name='%s',%s\n" %(params['name'],params['name'],unitsStr))
+            buff.writeIndented("    noAudio = %(No audio)s,\n" %(params))
+        elif self.params['backend'].val=='avbin':
             buff.writeIndented("%s = visual.MovieStim(win=win, name='%s',%s\n" %(params['name'],params['name'],unitsStr))
         else:
             buff.writeIndented("%s = visual.MovieStim2(win=win, name='%s',%s\n" %(params['name'],params['name'],unitsStr))
+            buff.writeIndented("    noAudio = %(No audio)s,\n" %(params))
         buff.writeIndented("    filename=%(movie)s,\n" %(params))
         buff.writeIndented("    ori=%(ori)s, pos=%(pos)s, opacity=%(opacity)s,\n" %(params))
         if self.params['size'].val != '':
