@@ -1,13 +1,15 @@
 # Part of the PsychoPy library
 # Copyright (C) 2015 Jonathan Peirce
 # Distributed under the terms of the GNU General Public License (GPL).
-
+from __future__ import print_function
 import StringIO, sys, codecs
 from components import getInitVals, getComponents, getAllComponents
 import psychopy
 from psychopy import data, __version__, logging
 from psychopy.constants import FOREVER
-from lxml import etree
+import xml.etree.ElementTree as xml
+from xml.dom import minidom
+
 import re, os
 try:
     _translate  # is the app-global text translation function defined?
@@ -112,7 +114,7 @@ class Experiment(object):
         self.psychopyVersion=__version__ #imported from components
         self.psychopyLibs=['visual','core','data','event','logging','sound']
         self.settings=getComponents(fetchIcons=False)['SettingsComponent'](parentName='', exp=self)
-        self._doc=None#this will be the xml.dom.minidom.doc object for saving
+        self._doc=xml.ElementTree() #this will be the xml.dom.minidom.doc object for saving
         self.namespace = NameSpace(self) # manage variable names
 
         #  _expHandler is a hack to allow saving data from components not inside
@@ -164,18 +166,12 @@ class Experiment(object):
                     '  Peirce, JW (2007) PsychoPy - Psychophysics software in Python. Journal of Neuroscience Methods, 162(1-2), 8-13.\n' +
                     '  Peirce, JW (2009) Generating stimuli for neuroscience using PsychoPy. Frontiers in Neuroinformatics, 2:10. doi: 10.3389/neuro.11.010.2008\n"""\n')
         script.write("\nfrom __future__ import division  # so that 1/3=0.333 instead of 1/3=0\n")
-        # This functionality is not ready to be exposed to end-users in a script
-        #if self.prefsApp['locale']:
-        #    # if locale is set explicitly as a pref, add it to the script:
-        #    localeValue = '.'.join(locale.getlocale())
-        #    script.write("from psychopy import localization\n" +
-        #             "localization.init(%s)\n\n" % repr(localeValue))
-        script.write("from psychopy import %s\n" % ', '.join(self.psychopyLibs) +
+        script.write("from psychopy import locale_setup, %s\n" % ', '.join(self.psychopyLibs) +
                     "from psychopy.constants import *  # things like STARTED, FINISHED\n" +
                     "import numpy as np  # whole numpy lib is available, prepend 'np.'\n" +
                     "from numpy import %s\n" % ', '.join(_numpyImports) +
                     "from numpy.random import %s\n" % ', '.join(_numpyRandomImports) +
-                    "import os  # handy system and path functions\n" + 
+                    "import os  # handy system and path functions\n" +
                     "import sys # to get file system encoding\n")
         script.write("\n")
         self.settings.writeStartCode(script) #present info dlg, make logfile
@@ -188,15 +184,15 @@ class Experiment(object):
 
     def saveToXML(self, filename):
         #create the dom object
-        self.xmlRoot = etree.Element("PsychoPy2experiment")
+        self.xmlRoot = xml.Element("PsychoPy2experiment")
         self.xmlRoot.set('version', __version__)
         self.xmlRoot.set('encoding', 'utf-8')
         #store settings
-        settingsNode=etree.SubElement(self.xmlRoot, 'Settings')
+        settingsNode=xml.SubElement(self.xmlRoot, 'Settings')
         for name, setting in self.settings.params.iteritems():
             settingNode=self._setXMLparam(parent=settingsNode,param=setting,name=name)
         #store routines
-        routinesNode=etree.SubElement(self.xmlRoot, 'Routines')
+        routinesNode=xml.SubElement(self.xmlRoot, 'Routines')
         for routineName, routine in self.routines.iteritems():#routines is a dict of routines
             routineNode = self._setXMLparam(parent=routinesNode,param=routine,name=routineName)
             for component in routine: #a routine is based on a list of components
@@ -204,9 +200,9 @@ class Experiment(object):
                 for name, param in component.params.iteritems():
                     paramNode=self._setXMLparam(parent=componentNode,param=param,name=name)
         #implement flow
-        flowNode=etree.SubElement(self.xmlRoot, 'Flow')
+        flowNode=xml.SubElement(self.xmlRoot, 'Flow')
         for element in self.flow:#a list of elements(routines and loopInit/Terms)
-            elementNode=etree.SubElement(flowNode, element.getType())
+            elementNode=xml.SubElement(flowNode, element.getType())
             if element.getType() == 'LoopInitiator':
                 loop=element.loop
                 name = loop.params['name'].val
@@ -220,9 +216,13 @@ class Experiment(object):
                 elementNode.set('name', element.loop.params['name'].val)
             elif element.getType() == 'Routine':
                 elementNode.set('name', '%s' %element.params['name'])
-        #write to disk
+        #convert to a pretty string
+        self._doc._setroot(self.xmlRoot)#update our document to use the new root
+        simpleString = xml.tostring(self.xmlRoot, 'utf-8')
+        pretty = minidom.parseString(simpleString).toprettyxml(indent="  ")
+        #then write to file
         f=codecs.open(filename, 'wb', 'utf-8')
-        f.write(etree.tostring(self.xmlRoot, encoding=unicode, pretty_print=True))
+        f.write(pretty)
         f.close()
     def _getShortName(self, longName):
         return longName.replace('(','').replace(')','').replace(' ','')
@@ -233,11 +233,14 @@ class Experiment(object):
         if hasattr(param,'getType'):
             thisType = param.getType()
         else: thisType='Param'
-        thisChild = etree.SubElement(parent,thisType)#creates and appends to parent
+        thisChild = xml.SubElement(parent,thisType)#creates and appends to parent
         thisChild.set('name',name)
-        if hasattr(param,'val'): thisChild.set('val',unicode(param.val))
-        if hasattr(param,'valType'): thisChild.set('valType',param.valType)
-        if hasattr(param,'updates'): thisChild.set('updates',unicode(param.updates))
+        if hasattr(param,'val'):
+            thisChild.set('val',unicode(param.val).replace("\n","&#10;"))
+        if hasattr(param,'valType'):
+            thisChild.set('valType',param.valType)
+        if hasattr(param,'updates'):
+            thisChild.set('updates',unicode(param.updates))
         return thisChild
     def _getXMLparam(self,params,paramNode):
         """params is the dict of params of the builder component (e.g. stimulus) into which
@@ -246,31 +249,33 @@ class Experiment(object):
         """
         name=paramNode.get('name')
         valType = paramNode.get('valType')
+        val = paramNode.get('val')
+        if not name == 'advancedParams':
+            val = val.replace("&#10;", "\n")
         if name=='storeResponseTime':
             return#deprecated in v1.70.00 because it was redundant
         elif name=='startTime':#deprecated in v1.70.00
             params['startType'].val =unicode('time (s)')
-            params['startVal'].val = unicode(paramNode.get('val'))
+            params['startVal'].val = unicode(val)
             return #times doesn't need to update its type or 'updates' rule
         elif name=='forceEndTrial':#deprecated in v1.70.00
-            params['forceEndRoutine'].val = bool(paramNode.get('val'))
+            params['forceEndRoutine'].val = bool(val)
             return #forceEndTrial doesn't need to update its type or 'updates' rule
         elif name=='forceEndTrialOnPress':#deprecated in v1.70.00
-            params['forceEndRoutineOnPress'].val = bool(paramNode.get('val'))
+            params['forceEndRoutineOnPress'].val = bool(val)
             return #forceEndTrial doesn't need to update its type or 'updates' rule
         elif name=='trialList':#deprecated in v1.70.00
-            params['conditions'].val = eval(paramNode.get('val'))
+            params['conditions'].val = eval(val)
             return #forceEndTrial doesn't need to update its type or 'updates' rule
         elif name=='trialListFile':#deprecated in v1.70.00
-            params['conditionsFile'].val = unicode(paramNode.get('val'))
+            params['conditionsFile'].val = unicode(val)
             return #forceEndTrial doesn't need to update its type or 'updates' rule
         elif name=='duration':#deprecated in v1.70.00
             params['stopType'].val =u'duration (s)'
-            params['stopVal'].val = unicode(paramNode.get('val'))
+            params['stopVal'].val = unicode(val)
             return #times doesn't need to update its type or 'updates' rule
         elif name=='allowedKeys' and valType=='str':#changed in v1.70.00
             #ynq used to be allowed, now should be 'y','n','q' or ['y','n','q']
-            val=paramNode.get('val')
             if len(val)==0:
                 newVal=val
             elif val[0]=='$':
@@ -284,31 +289,31 @@ class Experiment(object):
             params['allowedKeys'].val = newVal
             params['allowedKeys'].valType='code'
         elif name=='correctIf':#deprecated in v1.60.00
-            corrIf=paramNode.get('val')
+            corrIf=val
             corrAns=corrIf.replace('resp.keys==unicode(','').replace(')','')
             params['correctAns'].val=corrAns
             name='correctAns'#then we can fetch thte other aspects correctly below
         elif 'olour' in name:#colour parameter was Americanised in v1.61.00
             name=name.replace('olour','olor')
-            params[name].val = paramNode.get('val')
+            params[name].val = val
         elif name=='times':#deprecated in v1.60.00
-            exec('times=%s' %paramNode.get('val'))
+            exec('times=%s' %val)
             params['startType'].val =unicode('time (s)')
             params['startVal'].val = unicode(times[0])
             params['stopType'].val =unicode('time (s)')
             params['stopVal'].val = unicode(times[1])
             return #times doesn't need to update its type or 'updates' rule
         elif name in ['Begin Experiment', 'Begin Routine', 'Each Frame', 'End Routine', 'End Experiment']:
-            params[name].val = paramNode.get('val')
+            params[name].val = val
             params[name].valType = 'extendedCode' #changed in 1.78.00
             return #so that we don't update valTyp again below
         elif name == 'Saved data folder':
             #deprecated in 1.80 for more complete data filename control
-            params[name] = Param(paramNode.get('val'), valType='code', allowedTypes=[],
+            params[name] = Param(val, valType='code', allowedTypes=[],
                 hint=_translate("Name of the folder in which to save data and log files (blank defaults to the builder pref)"),
                 categ='Data')
         elif 'val' in paramNode.keys():
-            if paramNode.get('val')=='window units':#changed this value in 1.70.00
+            if val=='window units':#changed this value in 1.70.00
                 params[name].val = 'from exp settings'
             # in v1.80.00, several RatingScale API and Param fields were changed
             # Try to avoid a KeyError in these cases so can load the experiment,
@@ -317,7 +322,7 @@ class Experiment(object):
                 return
             elif name == 'customize_everything':
                 # Try to auto-update the code:
-                v = paramNode.get('val')  # python code, not XML
+                v = val  # python code, not XML
                 v = v.replace('markerStyle', 'marker').replace('customMarker', 'marker')
                 v = v.replace('stretchHoriz', 'stretch').replace('displaySizeFactor', 'size')
                 v = v.replace('textSizeFactor', 'textSize')
@@ -328,11 +333,11 @@ class Experiment(object):
                 params[name].val = v
             else:
                 if name in params:
-                    params[name].val = paramNode.get('val')
+                    params[name].val = val
                 else:
                     #we found an unknown parameter (probably from the future)
-                    params[name] = Param(paramNode.get('val'),
-                                    valType=paramNode.get('val'), allowedTypes=[],
+                    params[name] = Param(val,
+                                    valType=paramNode.get('valType'), allowedTypes=[],
                                     hint=_translate("This parameter is not known by this version of PsychoPy. It might be worth upgrading"))
                     params[name].allowedTypes = paramNode.get('allowedTypes')
                     if params[name].allowedTypes is None:
@@ -347,11 +352,7 @@ class Experiment(object):
         if 'valType' in paramNode.keys():
             params[name].valType = paramNode.get('valType')
             # compatibility checks:
-            if name=='text' and paramNode.get('valType')=='code':
-                params[name].valType='str'# these components were changed in v1.60.01
-            elif name=='correctAns' and paramNode.get('valType')=='code' and paramNode.getparent().tag=="TextComponent":
-                params[name].valType='str'# these components were changed in v1.60.01
-            elif name in ['allowedKeys'] and paramNode.get('valType')=='str':
+            if name in ['allowedKeys'] and paramNode.get('valType')=='str':
                 params[name].valType='code'# these components were changed in v1.70.00
             elif name == 'Selected rows': #changed in 1.81.00 from 'code' to 'str' to allow string or variable
                 params[name].valType = 'str'
@@ -362,12 +363,8 @@ class Experiment(object):
     def loadFromXML(self, filename):
         """Loads an xml file and parses the builder Experiment from it
         """
-        #open the file using a parser that ignores prettyprint blank text
-        parser = etree.XMLParser(remove_blank_text=True)
-        f=open(filename)
-        self._doc=etree.XML(f.read(),parser)
-        f.close()
-        root=self._doc#.getroot()
+        self._doc.parse(filename)
+        root=self._doc.getroot()
 
         #some error checking on the version (and report that this isn't valid .psyexp)?
         filename_base = os.path.basename(filename)
@@ -398,6 +395,7 @@ class Experiment(object):
             self.setExpName(shortName)
         #fetch routines
         routinesNode=root.find('Routines')
+        allCompons = getAllComponents(self.prefsBuilder['componentsFolders'], fetchIcons=False)
         for routineNode in routinesNode:#get each routine node from the list of routines
             routine_good_name = self.namespace.makeValid(routineNode.get('name'))
             if routine_good_name != routineNode.get('name'):
@@ -407,16 +405,16 @@ class Experiment(object):
             #self._getXMLparam(params=routine.params, paramNode=routineNode)
             self.routines[routineNode.get('name')]=routine
             for componentNode in routineNode:
-                allCompons = getAllComponents(self.prefsBuilder['componentsFolders'])
+
                 componentType=componentNode.tag
                 if componentType in allCompons:
                     #create an actual component of that type
-                    component=getAllComponents(self.prefsBuilder['componentsFolders'])[componentType](\
+                    component=allCompons[componentType](\
                         name=componentNode.get('name'),
                         parentName=routineNode.get('name'), exp=self)
                 else:
                     #create UnknownComponent instead
-                    component=getAllComponents(self.prefsBuilder['componentsFolders'])['UnknownComponent'](\
+                    component=allCompons['UnknownComponent'](\
                         name=componentNode.get('name'),
                         parentName=routineNode.get('name'), exp=self)
                 # check for components that were absent in older versions of the builder and change the default behavior
@@ -506,53 +504,53 @@ class Param:
     """Defines parameters for Experiment Components
     A string representation of the parameter will depend on the valType:
 
-    >>> print Param(val=[3,4], valType='num')
+    >>> print(Param(val=[3,4], valType='num'))
     asarray([3, 4])
-    >>> print Param(val=3, valType='num') # num converts int to float
+    >>> print(Param(val=3, valType='num')) # num converts int to float
     3.0
-    >>> print Param(val=3, valType='str') # str keeps as int, converts to code
+    >>> print(Param(val=3, valType='str') # str keeps as int, converts to code
     3
-    >>> print Param(val='3', valType='str') # ... and keeps str as str
+    >>> print(Param(val='3', valType='str')) # ... and keeps str as str
     '3'
-    >>> print Param(val=[3,4], valType='str') # val is <type 'list'> -> code
+    >>> print(Param(val=[3,4], valType='str')) # val is <type 'list'> -> code
     [3, 4]
-    >>> print Param(val='[3,4]', valType='str')
+    >>> print(Param(val='[3,4]', valType='str'))
     '[3,4]'
-    >>> print Param(val=[3,4], valType='code')
+    >>> print(Param(val=[3,4], valType='code'))
     [3, 4]
 
     >>> #### auto str -> code:  at least one non-escaped '$' triggers str -> code: ####
-    >>> print Param('[x,y]','str') # str normally returns string
+    >>> print(Param('[x,y]','str')) # str normally returns string
     '[x,y]'
-    >>> print Param('$[x,y]','str') # code, as triggered by $
+    >>> print(Param('$[x,y]','str')) # code, as triggered by $
     [x,y]
-    >>> print Param('[$x,$y]','str') # code, redundant $ ok, cleaned up
+    >>> print(Param('[$x,$y]','str')) # code, redundant $ ok, cleaned up
     [x,y]
-    >>> print Param('[$x,y]','str') # code, a $ anywhere means code
+    >>> print(Param('[$x,y]','str')) # code, a $ anywhere means code
     [x,y]
-    >>> print Param('[x,y]$','str') # ... even at the end
+    >>> print(Param('[x,y]$','str')) # ... even at the end
     [x,y]
-    >>> print Param('[x,\$y]','str') # string, because the only $ is escaped
+    >>> print(Param('[x,\$y]','str')) # string, because the only $ is escaped
     '[x,$y]'
-    >>> print Param('[x,\ $y]','str') # improper escape -> code (note that \ is not adjacent to $)
+    >>> print(Param('[x,\ $y]','str')) # improper escape -> code (note that \ is not adjacent to $)
     [x,\ y]
-    >>> print Param('/$[x,y]','str') # improper escape -> code (/ is not the same as \)
+    >>> print(Param('/$[x,y]','str')) # improper escape -> code (/ is not the same as \)
     /[x,y]
-    >>> print Param('[\$x,$y]','str') # code, python syntax error
+    >>> print(Param('[\$x,$y]','str')) # code, python syntax error
     [$x,y]
-    >>> print Param('["\$x",$y]','str') # ... python syntax ok
+    >>> print(Param('["\$x",$y]','str') # ... python syntax ok
     ["$x",y]
-    >>> print Param("'$a'",'str') # code, with the code being a string, $ removed
+    >>> print(Param("'$a'",'str')) # code, with the code being a string, $ removed
     'a'
-    >>> print Param("'\$a'",'str') # string, with the string containing a string, $ escaped (\ removed)
+    >>> print(Param("'\$a'",'str')) # string, with the string containing a string, $ escaped (\ removed)
     "'$a'"
-    >>> print Param('$$$$$myPathologicalVa$$$$$rName','str')
+    >>> print(Param('$$$$$myPathologicalVa$$$$$rName','str'))
     myPathologicalVarName
-    >>> print Param('\$$$$$myPathologicalVa$$$$$rName','str')
+    >>> print(Param('\$$$$$myPathologicalVa$$$$$rName','str'))
     $myPathologicalVarName
-    >>> print Param('$$$$\$myPathologicalVa$$$$$rName','str')
+    >>> print(Param('$$$$\$myPathologicalVa$$$$$rName','str'))
     $myPathologicalVarName
-    >>> print Param('$$$$\$$$myPathologicalVa$$$\$$$rName','str')
+    >>> print(Param('$$$$\$$$myPathologicalVa$$$\$$$rName','str'))
     $myPathologicalVa$rName
     """
 
@@ -622,7 +620,7 @@ class Param:
         elif self.valType == 'bool':
             return "%s" %(self.val)
         else:
-            raise TypeError, "Can't represent a Param of type %s" %self.valType
+            raise TypeError("Can't represent a Param of type %s" %self.valType)
 
 class TrialHandler(object):
     """A looping experimental control object
@@ -692,7 +690,7 @@ class TrialHandler(object):
         #write the code
         buff.writeIndentedLines("\n# set up handler to look after randomisation of conditions etc\n")
         buff.writeIndented("%(name)s = data.TrialHandler(nReps=%(nReps)s, method=%(loopType)s, \n" %(inits))
-        buff.writeIndented("    extraInfo=expInfo, originPath=%s,\n" %repr(self.exp.expPath))
+        buff.writeIndented("    extraInfo=expInfo, originPath=-1,\n")
         buff.writeIndented("    trialList=%s,\n" %(condsStr))
         buff.writeIndented("    seed=%(random seed)s, name='%(name)s')\n" %(inits))
         buff.writeIndented("thisExp.addLoop(%(name)s)  # add the loop to the experiment\n" %self.params)
@@ -813,7 +811,7 @@ class StairHandler(object):
         buff.writeIndented("    nReversals=%(N reversals)s, nTrials=%(nReps)s, \n" %self.params)
         buff.writeIndented("    nUp=%(N up)s, nDown=%(N down)s,\n" %self.params)
         buff.writeIndented("    minVal=%(min value)s, maxVal=%(max value)s,\n" %self.params)
-        buff.writeIndented("    originPath=%s" %repr(self.exp.expPath))
+        buff.writeIndented("    originPath=-1")
         buff.write(", name='%(name)s')\n"%self.params)
         buff.writeIndented("thisExp.addLoop(%(name)s)  # add the loop to the experiment" %self.params)
         buff.writeIndented("level = %s = %s  # initialise some vals\n" %(self.thisName, self.params['start value']))
@@ -888,7 +886,7 @@ class MultiStairHandler(object):
         buff.writeIndented("%(name)s = data.MultiStairHandler(stairType=%(stairType)s, name='%(name)s',\n" %(self.params))
         buff.writeIndented("    nTrials=%(nReps)s,\n" %self.params)
         buff.writeIndented("    conditions=conditions,\n")
-        buff.writeIndented("    originPath=%s" %repr(self.exp.expPath))
+        buff.writeIndented("    originPath=-1")
         buff.write(")\n"%self.params)
         buff.writeIndented("thisExp.addLoop(%(name)s)  # add the loop to the experiment\n" %self.params)
         buff.writeIndented("# initialise values for first condition\n")
@@ -1078,16 +1076,16 @@ class Flow(list):
             for field, key, component, routine in trailingWhitespace:
                 warnings.append( msg % (field, routine.params['name'],
                                 component.params['name'], key.capitalize()) )
-            print 'Note: Trailing white-space removed:\n ',
-            print '\n  '.join(list(set(warnings)))  # non-redundant, order unknown
+            print('Note: Trailing white-space removed:\n ',end='')
+            print('\n  '.join(list(set(warnings))))  # non-redundant, order unknown
         if constWarnings:
             warnings = []
             msg = '"%s", in Routine %s (%s: %s)'
             for field, key, component, routine in constWarnings:
                 warnings.append( msg % (field, routine.params['name'],
                                 component.params['name'], key.capitalize()) )
-            print 'Note: Dynamic code seems intended but updating is "constant":\n ',
-            print '\n  '.join(list(set(warnings)))  # non-redundant, order unknown
+            print('Note: Dynamic code seems intended but updating is "constant":\n ',end='')
+            print('\n  '.join(list(set(warnings))))  # non-redundant, order unknown
     def writeStartCode(self, script):
         """Write the code that comes before the Window is created
         """
@@ -1359,7 +1357,7 @@ class NameSpace():
 
     The aim is to help detect and avoid name-space collisions from user-entered variable names.
     Track four groups of variables:
-        numpy =    part of numpy or numpy.random (maybe its ok for a user to redefine these?)
+        numpy =    part of numpy or numpy.random (maybe it's ok for a user to redefine these?)
         psychopy = part of psychopy, such as event or data; include os here
         builder =  used internally by the builder when constructing an experiment
         user =     used 'externally' by a user when programming an experiment
