@@ -11,11 +11,18 @@ from psychopy.app._psychopyApp import *
 #now used solely as a launcher for the app, not as the app itself.
 
 if __name__=='__main__':
+    if '-x' in sys.argv:
+        # enable execution of .py script from command line using StandAlone python
+        targetScript = sys.argv[sys.argv.index('-x') + 1]
+        from psychopy import core
+        import os
+        core.shellCall([sys.executable, os.path.abspath(targetScript)])
+        sys.exit()
     if '-v' in sys.argv or '--version' in sys.argv:
-        print 'PsychoPy2, version %s (c)Jonathan Peirce, 2015, GNU GPL license' %psychopy.__version__
+        print('PsychoPy2, version %s (c)Jonathan Peirce, 2015, GNU GPL license' %psychopy.__version__)
         sys.exit()
     if '-h' in sys.argv or '--help' in sys.argv:
-        print """Starts the PsychoPy2 application.
+        print("""Starts the PsychoPy2 application.
 
 Usage:  python PsychoPy.py [options] [file]
 
@@ -30,6 +37,7 @@ depends on the type of the [file]:
 Options:
     -c, --coder, coder       opens coder view only
     -b, --builder, builder   opens builder view only
+    -x script.py             directly execute script.py using StandAlone python
 
     -v, --version    prints version and exits
     -h, --help       prints this help and exit
@@ -37,7 +45,7 @@ Options:
     --firstrun       launches configuration wizard
     --no-splash      suppresses splash screen
 
-"""
+""")
         sys.exit()
 
     else:
