@@ -27,11 +27,11 @@ for thisTrial in trials: #handler can act like a for loop
     trials.data.add('choice', thisChoice) 
     nDone += 1  #just for a quick reference
     
-    print 'trial %i had position %s in the list (sf=%.1f)' \
-          %(nDone, trials.thisIndex, thisTrial['sf'])
+    print('trial %i had position %s in the list (sf=%.1f)' \
+          %(nDone, trials.thisIndex, thisTrial['sf']))
     
 #after the experiment
-print '\n'
+print('\n')
 trials.printAsText(stimOut=['sf','ori'], #write summary data to screen 
                   dataOut=['RT_mean','RT_std', 'choice_raw'])
 trials.saveAsText(fileName='testData', # also write summary data to a text file
