@@ -8,9 +8,9 @@ infoDlg = gui.DlgFromDict(dictionary=info, title='TestExperiment',
     tip={'Observer': 'trained visual observer, initials'},
     fixed=['ExpVersion'])#this attribute can't be changed by the user
 if infoDlg.OK: #this will be True (user hit OK) or False (cancelled)
-    print info
+    print(info)
 else: 
-    print 'User Cancelled'
+    print('User Cancelled')
 
 #this alternative uses a Dlg and you manually extract the data (more control: eg, text, color)
 myDlg = gui.Dlg(title="JWP's experiment", pos=(200,400))
@@ -23,5 +23,6 @@ myDlg.addField('',45)
 myDlg.show()#you have to call show() for a Dlg (it gets done implicitly by a DlgFromDict)
 if myDlg.OK:
     thisInfo = myDlg.data #this will be a list of data returned from each field added in order
-    print thisInfo
-else: print 'user cancelled'
+    print(thisInfo)
+else:
+    print('user cancelled')
