@@ -19,7 +19,7 @@ stim1 = visual.ShapeStim(win,
                  fillColor=None, #beware, with convex shapes fill colors don't work
                  vertices=arrowVertices,#choose something from the above or make your own
                  closeShape=True,#do you want the final vertex to complete a loop with 1st?
-                 pos= [0,0], #the anchor (rotaion and vertices are position with respect to this)
+                 pos= [0,0], #the anchor (rotation and vertices are position with respect to this)
                  interpolate=True,
                  opacity=0.9,
                  autoLog=False)#this stim changes too much for autologging to be useful
@@ -31,7 +31,7 @@ stim2 = visual.ShapeStim(win,
                  fillColorSpace='rgb',
                  vertices=sqrVertices,#choose something from the above or make your own
                  closeShape=True,#do you want the final vertex to complete a loop with 1st?
-                 pos= [0.5,0.5], #the anchor (rotaion and vertices are position with respect to this)
+                 pos= [0.5,0.5], #the anchor (rotation and vertices are position with respect to this)
                  interpolate=True,
                  opacity=0.9,
                  autoLog=False)#this stim changes too much for autologging to be useful
@@ -47,4 +47,4 @@ while True:
  
     win.flip()
     if event.getKeys(keyList=['escape', 'q']):
-        core.quit()
\ No newline at end of file
+        core.quit()
