@@ -654,10 +654,14 @@ class MainFrame(wx.Frame):
         self.unSavedMonitor=True
     def onChangeScrDist(self, event):
         newVal = unicodeToFloat(self.ctrlScrDist.GetValue())
+        if newVal == 0:
+            newVal = None # zero means "not set" but can't be used in calculations
         self.currentMon.setDistance( newVal )
         self.unSavedMonitor=True
     def onChangeScrWidth(self, event):
         newVal = unicodeToFloat(self.ctrlScrWidth.GetValue())
+        if newVal == 0:
+            newVal = None # zero means "not set" but can't be used in calculations
         self.currentMon.setWidth( newVal )
         self.unSavedMonitor=True
     def onChangeScrPixHoriz(self, event):
@@ -965,9 +969,6 @@ class MainFrame(wx.Frame):
         figureCanvas.draw()#update the canvas
         plotWindow.addCanvas(figureCanvas)
 
-    def onClosePlotWindow(self, event):
-        print event
-
 class GammaLumValsDlg(wx.Dialog):
     '''a dialogue to manually get the luminance values recorded for each level'''
     def __init__(self, parent, levels):
