@@ -47,9 +47,9 @@ class Dlg(QtGui.QDialog):
         myDlg.addField('Group:', choices=["Test", "Control"])
         ok_data = myDlg.show()  # show dialog and wait for OK or Cancel
         if myDlg.OK:  # or if ok_data is not None
-            print ok_data
+            print(ok_data)
         else:
-            print 'user cancelled'
+            print('user cancelled')
     """
 
     def __init__(self, title=_translate('PsychoPy Dialog'),
@@ -194,7 +194,7 @@ class Dlg(QtGui.QDialog):
                         "handleLineEditChange: inputFieldName={0}, type={1}, "
                         "value={2}".format(
                             label, thisType, self.data[ix]))
-                except Exception, e:
+                except Exception as e:
                     self.data[ix] = unicode(new_text)
                     logging.error(
                         'Error in handleLineEditChange: inputFieldName={0}, '
@@ -321,8 +321,9 @@ class DlgFromDict(Dlg):
         info = {'Observer':'jwp', 'GratingOri':45, 'ExpVersion': 1.1, 'Group': ['Test', 'Control']}
         dictDlg = gui.DlgFromDict(dictionary=info, title='TestExperiment', fixed=['ExpVersion'])
         if dictDlg.OK:
-            print info
-        else: print 'User Cancelled'
+            print(info)
+        else:
+            print('User Cancelled')
 
     In the code above, the contents of *info* will be updated to the values
     returned by the dialogue box.
@@ -343,7 +344,6 @@ class DlgFromDict(Dlg):
             keys = order + list(set(keys).difference(set(order)))
         types=dict([])
         for field in keys:
-            #DEBUG: print field, type(dictionary[field])
             types[field] = type(self.dictionary[field])
             tooltip = ''
             if field in tip.keys():
@@ -563,25 +563,25 @@ if __name__ == '__main__':
     dlg.addFixedField("ReadOnly dropdown", initial=2,
                       choices=['R1', 'R2', 'R3'], tip="This field is readonly.")
     ok_data = dlg.show()
-    print "Dlg ok_data:", ok_data
+    print("Dlg ok_data:", ok_data)
 
     # Test Dict Dialog
 
     info = {'Observer':'jwp', 'GratingOri':45, 'ExpVersion': 1.1, 'Group': ['Test', 'Control']}
     dictDlg = DlgFromDict(dictionary=info, title='TestExperiment', fixed=['ExpVersion'])
     if dictDlg.OK:
-        print info
+        print(info)
     else:
-        print 'User Cancelled'
+        print('User Cancelled')
 
 
     # Test File Dialogs
 
     fileToSave = fileSaveDlg(initFileName='__init__.pyc')
-    print "fileToSave: [", fileToSave, "]", type(fileToSave)
+    print("fileToSave: [", fileToSave, "]", type(fileToSave))
 
     fileToOpen = fileOpenDlg()
-    print "fileToOpen:", fileToOpen
+    print("fileToOpen:", fileToOpen)
 
     # Test Alert Dialogs
 
