@@ -1,16 +1,17 @@
 import sys
-from psychopy.tests import utils
+import pytest
 
 def test_essential_imports():
     import wx
     import numpy
     import scipy
     import matplotlib
-    import pygame
+    #import pygame  # soft dependency only
     import pyglet
     import OpenGL
     import openpyxl
     import lxml
+    import pandas
 
 def test_extra_imports():
     # only Jon needs to run this, so test first if you are him!
@@ -22,22 +23,30 @@ def test_extra_imports():
         import pwd
         user = pwd.getpwuid(os.getuid()).pw_name
     if user not in ['jwp','lpzjwp']:
-        utils.skip('Testing extra imports is only needed for building Standalone distributions')
+        pytest.skip('Testing extra imports is only needed for building Standalone distributions')
     #OK, it's Jon , so run it
+    import bidi #for right-left languages
+    import yaml, msgpack, gevent
+    import IPython, tornado
+    import psychopy_ext
+    import IPython, tornado
+    import psychopy_ext
+    import IPython, tornado, zmq, jinja2, jsonschema
+    import psychopy_ext, pandas, seaborn
+    #avbin
+    import pyglet
+    assert pyglet.media.have_avbin
     import serial
-    import pp
+    import hid
+    import pyo
+    if sys.platform=='win32':
+        import parallel
+    #specific hardware libs
     import egi
     try:
         import labjack
     except:
         import u3, u6, ue9, LabJackPython
     import ioLabs
-    import hid
-    import pyo
-    #avbin
-    import pyglet
-    assert pyglet.media.have_avbin
     #platform specific
-    if sys.platform=='win32':
-        import parallel
     import pylink
