@@ -1,11 +1,9 @@
-import pyglet
-from pyglet.window import key
-from psychopy.visual import Window, shape, TextStim, GratingStim, Circle
+
+from psychopy.visual import Window
 from psychopy.visual.windowframepack import ProjectorFramePacker
-from psychopy import event, core
+
 from psychopy.constants import *
-from psychopy.tests import utils
-import pytest, copy
+import pytest
 
 """define ProjectorFramePack configurations, test the logic
 
@@ -28,14 +26,14 @@ class Test_class_ProjectorFramePacker:
         self.win.close()
 
     def flip (self, frames=120):
-        for i in range(frames): 
+        for i in range(frames):
             self.win.flip()
 
 if __name__ == '__main__':
     cls = Test_class_ProjectorFramePacker()
     cls.setup_class()
     originalFPS = cls.win.fps()
-    print 'originalFPS = ' + str(originalFPS)
+    print('originalFPS = ' + str(originalFPS))
     cls.flip(3)
     assert (cls.win.frames == 3)
     assert (cls.packer.flipCounter == 3)
@@ -43,6 +41,6 @@ if __name__ == '__main__':
     assert (cls.win.frames == 36)
     assert (cls.packer.flipCounter == 36)
     finalFPS = cls.win.fps()
-    print 'finalFPS = ' + str(finalFPS)
+    print('finalFPS = ' + str(finalFPS))
     cls.teardown_class()
 
