@@ -70,7 +70,7 @@ for compName in sorted(allComp):
             err = order + ' <== ' + targetTag[tag]
         except IndexError: # missing
             err = order + ' <==> NEW (no matching param in original)'
-        print err.encode('utf8')
+        print(err.encode('utf8'))
         mismatches.append(err)
     for parName in comp.params.keys():
         # default is what you get from param.__str__, which returns its value
@@ -96,7 +96,7 @@ for compName in sorted(allComp):
                     err = line + ' <== ' + targetTag[tag]
                 except KeyError: # missing
                     err = line + ' <==> NEW (no matching param in original)'
-                print err.encode('utf8')
+                print(err.encode('utf8'))
                 mismatches.append(err)
 
 #return mismatches
