@@ -3,7 +3,13 @@
 from psychopy.visual import Window, ShapeStim
 from psychopy import event, core, monitors
 from psychopy.constants import NOT_STARTED
-import pyglet, pygame
+import pyglet
+from pyglet.window.mouse import LEFT, MIDDLE, RIGHT
+try:
+    import pygame
+    havePygame = True
+except:
+    havePygame = False
 import pytest
 import copy
 import threading
@@ -50,6 +56,22 @@ class _baseTest:
                 m.setPos((0,0))
                 m.getPos()
 
+    def test_emulated_mouse(self):
+        mouse = event.Mouse()  # real mouse
+        event.mouseButtons = [0,0,0]
+        [c.reset() for c in event.mouseClick]  # mouse click RT clocks
+        assert not any(event.mouseButtons)
+        assert not any(event.mouseTimes)
+
+        # fake clicks on all buttons:
+        event._onPygletMousePress(0, 0, LEFT | MIDDLE | RIGHT, None, emulated=True)
+        assert all(mouse.getPressed())
+        assert all([RT < 0.01 for RT in event.mouseTimes])  # should be < .0001
+
+        # fake release all buttons:
+        event._onPygletMouseRelease(0, 0, LEFT | MIDDLE | RIGHT, None, emulated=True)
+        assert not any(event.mouseButtons)
+
     def test_mouse_clock(self):
         x, y = 0, 0
         scroll_x, scroll_y = 1, 1
@@ -125,12 +147,13 @@ class _baseTest:
             keyThread.start()
             result = event.waitKeys(maxWait=.1, keyList=[k], timeStamped=c)
             assert result[0][0] == k
-            assert result[0][1] - delay < .001  # should be ~0 except for execution time
+            assert result[0][1] - delay < .01  # should be ~0 except for execution time
 
     def test_misc(self):
         assert event.xydist([0,0], [1,1]) == sqrt(2)
 
     def test_mouseMoved(self):
+
         if travis:
             pytest.skip()  # failing on travis-ci
 
@@ -170,8 +193,6 @@ class _baseTest:
         m.getPressed(getTime=True)
 
     def test_isPressedIn(self):
-        #pytest.skip()
-
         m = event.Mouse(self.win, newPos=(0,0))
         s = ShapeStim(self.win, vertices=[[10,10],[10,-10],[-10,-10],[-10,10]], autoLog=False)
         if not s.contains(m.getPos()):
