@@ -17,8 +17,13 @@ from psychopy.visual.window import Window, getMsPerFrame, openWindows
 # non-private helpers
 from psychopy.visual.helpers import pointInPolygon, polygonsOverlap
 
-# stimuli derived from object or MinimalStim
+# absolute essentials (nearly all experiments will need these)
 from psychopy.visual.basevisual import BaseVisualStim
+from psychopy.visual.image import ImageStim
+from psychopy.visual.text import TextStim
+
+lazyImports = """
+# stimuli derived from object or MinimalStim
 from psychopy.visual.aperture import Aperture
 from psychopy.visual.custommouse import CustomMouse
 from psychopy.visual.elementarray import ElementArrayStim
@@ -28,16 +33,11 @@ from psychopy.visual.simpleimage import SimpleImageStim
 # stimuli derived from BaseVisualStim
 from psychopy.visual.dot import DotStim
 from psychopy.visual.grating import GratingStim
-from psychopy.visual.image import ImageStim
+from psychopy.visual.secondorder import EnvelopeGrating
 from psychopy.visual.movie import MovieStim
-
-try:
-    from psychopy.visual.movie2 import MovieStim2
-except:
-    logging.warn("Movie2 stim could not be imported and won't be available")
-
+from psychopy.visual.movie2 import MovieStim2
+from psychopy.visual.movie3 import MovieStim3
 from psychopy.visual.shape import ShapeStim
-from psychopy.visual.text import TextStim
 
 # stimuli derived from GratingStim
 from psychopy.visual.bufferimage import BufferImageStim
@@ -52,17 +52,10 @@ from psychopy.visual.rect import Rect
 # stimuli derived from Polygon
 from psychopy.visual.circle import Circle
 
-# TextBox alternative to TextStim
-try:    
-    # Ensure monospace Fonts are available ....
-    font_names = []
-    import textbox
-    from textbox import getFontManager
-    fm=getFontManager()
-    font_names = fm.getFontFamilyNames()
-    assert len(font_names) > 0
-    from textbox import TextBox
-except Exception, e:
-    logging.warn("TextBox stim could not be imported and won't be available.")
-    if len(font_names) == 0:
-        logging.warn("TextBox Font Manager Found No Fonts.")
+from psychopy.visual.textbox import TextBox
+"""
+try:
+    from psychopy.contrib.lazy_import import lazy_import
+    lazy_import(globals(), lazyImports)
+except:
+    exec(lazyImports)
