@@ -12,12 +12,14 @@ python setup.py bdist_egg
 rm psychopy/demos/*.pyc
 rm psychopy/prefSite.cfg
 
-sudo rm -r dist/PsychoPy2.app
-sudo rm -r ../dist/PsychoPy2.app
+sudo rm -r dist/PsychoPy2.app #the previous version
+sudo rm -r ../dist/PsychoPy2.app #the previous version in 'main' location
 python setupApp.py py2app
 sudo chmod -R g+w dist/PsychoPy2.app
+#remove matplotlib tests (45mb)
+rm -r dist/PsychoPy2.app/Contents/Resources/lib/python2.7/matplotlib/tests
 #strip all other architectures from binaries and move both to ../dist
-ditto --rsrc --arch i386 dist/PsychoPy2.app ../dist/PsychoPy2.app
+echo stripping i386 using ditto
+ditto --rsrc --arch x86_64 dist/PsychoPy2.app ../dist/PsychoPy2.app
 mv dist/PsychoPy2.app ../dist/PsychoPy2_fat.app
 
-mv dist/* ../dist/
